import styles from './styles.module.css'
import Options from "../options";
import Arguments from "../arguments";
import {OptionInterface} from "../option";
import {ArgumentInterface} from "../argument";
import {Provider} from "./context";
import {useEffect, useState} from "react";

export interface CommandInterface {
    class: string,
    name: string,
    description: string,
    options: OptionInterface[],
    arguments: ArgumentInterface[],
}

interface CommandComponentInterface {
    command: CommandInterface,
    callback: any,
}

export default function Command({command, callback}: CommandComponentInterface) {
    const [optionList, setOptionList] = useState<Record<string, any>>({});
    const [argumentList, setArgumentList] = useState<Record<string, any>>({});

    useEffect(() => {
        callback && callback(command.name, optionList, argumentList)
    }, [optionList, argumentList])

    return (
        <Provider value={{optionList, setOptionList, argumentList, setArgumentList}}>
            <div>
                <div title={command.description}>
                    {command.name}&nbsp;
                    <Options optionList={command.options} />
                    <Arguments argumentList={command.arguments} />
                </div>
            </div>
        </Provider>
    )
}
